.. Copyright (C) 2017 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2017 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

`The Comprehensive R Archive Network <https://cran.r-project.org/>`_ (CRAN) is
a repository of precompiled packages for the R statistical programming language
environment. This role can be used to enable the upstream CRAN APT repositories
and install R packages, both via APT and via R itself.
